#! Flux2D 20.1

############################################################################
######## Vibration Analysis - Export Magnetic Forces at Multi-Speed ########
############################################################################



#Define application
lastInstance = ApplicationMagneticTransient2D(domain2D=Domain2DPlane(lengthUnit=LengthUnit['MILLIMETER'],
                                                      depth='310'),
                               coilCoefficient=CoilCoefficientAutomatic(),
                               transientInitialization=TransientInitializationZeroInitialSolution())


#Define parameters
lastInstance = VariationParameterPilot(name='SPEED',
                        referenceValue=1080.0)

lastInstance = VariationParameterPilot(name='R_LOAD',
                        referenceValue=1.0E-4)

lastInstance = VariationParameterPilot(name='L_LOAD',
                        referenceValue=1.59E-4)
                        
lastInstance = VariationParameterPilot(name='F',
                        referenceValue=0.29)
                        
lastInstance = VariationParameterPilot(name='N_coil',
                        referenceValue=9.0)
                        


# Modifier parameters

lastInstance = VariationParameterFormula(name='FREQUENCY',
                          formula='SPEED/60*10/2')

lastInstance = VariationParameterFormula(name='OMEGA',
                          formula='2*Pi()*FREQUENCY')

lastInstance = VariationParameterTabulated(name='GAMMA',
                            xParameter=VariationParameter['SPEED'],
                            curvePoints=[XYCoordinates(xy=[88.597,
                                                           10.64]),
                                         XYCoordinates(xy=[265.792,
                                                           10.64]),
                                         XYCoordinates(xy=[442.986,
                                                           10.642]),
                                         XYCoordinates(xy=[620.181,
                                                           10.67]),
                                         XYCoordinates(xy=[824.113,
                                                           43.425]),
                                         XYCoordinates(xy=[1028.046,
                                                           61.758]),
                                         XYCoordinates(xy=[1231.978,
                                                           76.19])])


lastInstance = VariationParameterTabulated(name='RMS_CURRENT',
                            xParameter=VariationParameter['SPEED'],
                            curvePoints=[XYCoordinates(xy=[88.597,
                                                           90.0]),
                                         XYCoordinates(xy=[265.792,
                                                           90.0]),
                                         XYCoordinates(xy=[442.986,
                                                           90.0]),
                                         XYCoordinates(xy=[620.181,
                                                           90.0]),
                                         XYCoordinates(xy=[824.113,
                                                           90.0]),
                                         XYCoordinates(xy=[1028.046,
                                                           90.0]),
                                         XYCoordinates(xy=[1231.978,
                                                           90.0])])

#Import circuit

importCircuit(filename='Circuit_ModeMotor.xcir',
              importValue=1,
              ImportFELink=1)



#Define mechanical sets

lastInstance = MechanicalSetFixed(name='STATOR')

lastInstance = MechanicalSetRotation1Axis(name='ROTOR',
                           kinematics=RotatingImposedSpeed(velocity='SPEED',
                                                           initialPosition='0'),
                           rotationAxis=RotationZAxis(coordSys=CoordSys['XY1'],
                                                      pivot=['0',
                                                             '0']))

#Import/ create materials
import os
INSTALL = os.environ["INSTALLFLUX"] + "/.."

importMaterial(fileName=INSTALL + '/Materials/FLUX_111_MATERI.DAT', materialNames=['FLU_ALUMINIUM        :','FLU_M800_65A         :'])

lastInstance = Material(name='MAGNET_NdFeB',
         propertyBH=PropertyBhMagnetOneDirection(br='1.19',
                                                 mur='1.038'),
         propertyJE=PropertyJeLinear(rho='0.18E-5'))

importMaterial(fileName=INSTALL + '/Materials/FLUX_111_MATERI.DAT', materialNames=['FLU_COPPER           :'])

Material['FLU_COPPER'].propertyJE=PropertyJeTLinearFunction(slope='0.00427',
                                                            rhoConstant='0.1564E-07',
                                                            referenceTemperature=Temperature(temperature='0',
                                                                                             unit=Unit['CELSIUS_DEGREE']),
                                                            temperature=Temperature(temperature='90',
                                                                                    unit=Unit['CELSIUS_DEGREE']))
                                                                                    
#Create face regions

startMacroTransaction()
RegionFace['INFINITE'].magneticTransient2D=MagneticTransient2DFaceVacuum()

RegionFace['INFINITE'].mechanicalSet=MechanicalSet['STATOR']

endMacroTransaction()

lastInstance = RegionFace(name='AIR',
           magneticTransient2D=MagneticTransient2DFaceVacuum(),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='AIRGAP_STATOR',
           magneticTransient2D=MagneticTransient2DFaceVacuum(),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='AIRGAP_ROTOR',
           magneticTransient2D=MagneticTransient2DFaceVacuum(),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])
           
lastInstance = RegionFace(name='WEDGE',
           magneticTransient2D=MagneticTransient2DFaceVacuum(),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])
           
lastInstance = RegionFace(name='ROTOR',
           magneticTransient2D=MagneticTransient2DFaceLaminatedNonConducting(sheetIronMaterial=Material['FLU_M800_65A'],
                                                                             sheetIronThickness='0.35E-3',
                                                                             stackingFactor='0.97'),
           color=Color['Green'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionFace(name='SHAFT',
           magneticTransient2D=MagneticTransient2DFaceMagnetic(material=Material['FLU_ALUMINIUM']),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionFace(name='STATOR',
           magneticTransient2D=MagneticTransient2DFaceLaminatedNonConducting(sheetIronMaterial=Material['FLU_M800_65A'],
                                                                             sheetIronThickness='0.35E-3',
                                                                             stackingFactor='0.97'),
           color=Color['Green'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='Magnet_N',
           magneticTransient2D=MagneticTransient2DFaceSolidConductor(material=Material['MAGNET_NDFEB'],
                                                                     circuitType=Circuit(orientation=PositiveOrientation(),
                                                                                         component=SolidConductor2Terminals['SOLIDCONDUCTOR2TERMINALS_1'])),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionFace(name='MAGNET_S1',
           magneticTransient2D=MagneticTransient2DFaceSolidConductor(material=Material['MAGNET_NDFEB'],
                                                                     circuitType=Circuit(orientation=PositiveOrientation(),
                                                                                         component=SolidConductor2Terminals['SOLIDCONDUCTOR2TERMINALS_2'])),
           color=Color['Cyan'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])


lastInstance = RegionFace(name='MAGNET_S2',
           magneticTransient2D=MagneticTransient2DFaceSolidConductor(material=Material['MAGNET_NDFEB'],
                                                                     circuitType=Circuit(orientation=PositiveOrientation(),
                                                                                         component=SolidConductor2Terminals['SOLIDCONDUCTOR2TERMINALS_3'])),
           color=Color['Cyan'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['ROTOR'])


lastInstance = RegionFace(name='AN',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DNegative(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHA'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['White'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='AP',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHA'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['Black'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])




lastInstance = RegionFace(name='BN',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DNegative(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHB'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['Cyan'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='BP',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHB'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['Magenta'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])



lastInstance = RegionFace(name='CN',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DNegative(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHC'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['Yellow'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='CP',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='N_COIL',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['PHC'],
                                                                                                          fillFactor='F'),
                                                                    material=Material['FLU_COPPER']),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='TESTING_COIL_P',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='1',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['TESTING_COIL_CONDUCTOR'],
                                                                                                          fillFactor='0.1')),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionFace(name='TESTING_COIL_N',
           magneticTransient2D=MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DNegative(turnNumber='1',
                                                                                                          seriesParallel=AllInSeries(),
                                                                                                          electricComponent=CoilConductor['TESTING_COIL_CONDUCTOR'],
                                                                                                          fillFactor='0.1')),
           color=Color['Turquoise'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['STATOR'])



#Assign face region to faces

assignRegionToFaces(face=[Face[37]],
                    region=RegionFace['SHAFT'])

assignRegionToFaces(face=[Face[13]],
                    region=RegionFace['ROTOR'])

assignRegionToFaces(face=[Face[19]],
                    region=RegionFace['STATOR'])

assignRegionToFaces(face=[Face[39]],
                    region=RegionFace['AIR'])

assignRegionToFaces(face=[Face[18],
                          Face[16],
                          Face[17]],
                    region=RegionFace['AIRGAP_ROTOR'])

assignRegionToFaces(face=[Face[20]],
                    region=RegionFace['AIRGAP_STATOR'])

assignRegionToFaces(face=[Face[15]],
                    region=RegionFace['MAGNET_N'])

assignRegionToFaces(face=[Face[14]],
                    region=RegionFace['MAGNET_S1'])

assignRegionToFaces(face=[Face[38]],
                    region=RegionFace['MAGNET_S2'])


assignRegionToFaces(face=[Face[21]],
                    region=RegionFace['AIRGAP_STATOR'])

assignRegionToFaces(face=[Face[36],
                          Face[34],
                          Face[22],
                          Face[28],
                          Face[23],
                          Face[24],
                          Face[31]],
                    region=RegionFace['WEDGE'])

assignRegionToFaces(face=[Face[35]],
                    region=RegionFace['TESTING_COIL_P'])
                    
assignRegionToFaces(face=[Face[25]],
                    region=RegionFace['TESTING_COIL_N'])                    
                    
assignRegionToFaces(face=[Face[11],
                          Face[12],
                          Face[26]],
                    region=RegionFace['AP'])

assignRegionToFaces(face=[Face[8],
                          Face[27],
                          Face[7]],
                    region=RegionFace['CN'])

assignRegionToFaces(face=[Face[2],
                          Face[1],
                          Face[29]],
                    region=RegionFace['BP'])

assignRegionToFaces(face=[Face[3],
                          Face[4],
                          Face[30]],
                    region=RegionFace['AN'])

assignRegionToFaces(face=[Face[32],
                          Face[9],
                          Face[10]],
                    region=RegionFace['CP'])

assignRegionToFaces(face=[Face[33],
                          Face[5],
                          Face[6]],
                    region=RegionFace['BN'])
                                    
                    

#Orient magnets Br

orientRegSurfMaterial(region=RegionFace['MAGNET_N'],coordSys=CoordSys['XY1'],orientation='Direction',angle='36')
orientRegSurfMaterial(region=RegionFace['MAGNET_S1'],coordSys=CoordSys['XY1'],orientation='Direction',angle='180')
orientRegSurfMaterial(region=RegionFace['MAGNET_S2'],coordSys=CoordSys['XY1'],orientation='Direction',angle='72+180')

# New Spatial Parameter for Joule losses
lastInstance = SpatialParameterFormula(name='Joule_losses',
                        SpatialFormula='J*J*Rho/IO(F)')
                        

### Save project as
saveProjectAs('IKERMAQ_MULTISPEED_PHYSICS_CHECKED.FLU')
    
