#! Flux2D 20.1
import fluxTool
############################################################################
######## Vibration Analysis - Export Magnetic Forces at Multi-Speed ########
############################################################################


saveProjectAs('IKERMAQ_MULTISPEED_POSTPROCESSING.FLU')

openIODataContext(subtype='Mechanical')

# Create data support

lastInstance = ImportedMeshDataSupport(name='DataSupport_Tooth',
                        aspect='mesh',
                        visibility=Visibility['VISIBLE'],
                        color=Color['Turquoise'],
                        fileType=OptistructFile(filename='Mesh_forExportToothForce.fem'),
                        coordinateSystem=CoordSys['XY1'])


# Create data collection

lastInstance = RotatingMachineForcesCollection(name='DataCollection_ToothForce',
                                interval=AllSteps(),
                                support=SupportForRotatingMachineForces['DATASUPPORT_TOOTH'],
                                radiusValue='139',
                                radiusUnit=LengthUnit['MILLIMETER'],
                                pointsOnPerimeter=1080,
                                maxProjectionDistance=0.0)

lastInstance = FFTDerivedCollection(name='DataCollection_ToothForce_FFT_1',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=88.597),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_2',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=265.792),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_3',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=442.986),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_4',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=620.181),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_5',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=824.113),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_6',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=1028.046),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

lastInstance = FFTDerivedCollection(name='DATACOLLECTION_TOOTHFORCE_FFT_7',
                     dataCollectionToTransform=CollectionForFFTCollection['DATACOLLECTION_TOOTHFORCE'],
                     timeInterval=EvolutivePath(parameterSet=[SetParameterFixed(paramEvol=VariationParameter['SPEED'],
                                                                                currentValue=1231.978),
                                                              SetParameterXVariable(paramEvol=VariationParameter['ANGPOS_ROTOR'],
                                                                                    limitMin=72.0,
                                                                                    limitMax=144.0)]),
                     duplication=TRUE())

collectData()


# Create data visualizers

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DataVisualizer_ToothForce_Nodes_FFT_1',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_1'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_2',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_2'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_3',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_3'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_4',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_4'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_5',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_5'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_6',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_6'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_NODES_FFT_7',
                                              forceType='atNodes',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_7'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DataVisualizer_ToothForce_Global_FFT_1',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_1'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_2',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_2'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_3',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_3'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_4',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_4'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_5',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_5'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_6',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_6'],
                                              component='resulting')

lastInstance = Data_visualizer_harmonicforce_RotatingMachine(name='DATAVISUALIZER_TOOTHFORCE_GLOBAL_FFT_7',
                                              forceType='global',
                                              rank=0,
                                              forcesDataCollection=CollectionForRotatingMachineHarmonicForces['DATACOLLECTION_TOOTHFORCE_FFT_7'],
                                              component='resulting')


# Create data exports

fluxTool.createEmptyFolder('Forces_Files')

lastInstance = HarmonicForceOptiStructDataExport(name='DataExport_ToothForce_Nodes_FFT_1',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_1',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_1'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_2',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_2',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_2'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_3',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_3',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_3'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_4',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_4',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_4'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_5',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_5',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_5'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_6',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_6',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_6'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_NODES_FFT_7',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Node_7',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_7'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='atNodes')

lastInstance = HarmonicForceOptiStructDataExport(name='DataExport_ToothForce_Global_FFT_1',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_1',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_1'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_2',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_2',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_2'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_3',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_3',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_3'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_4',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_4',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_4'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_5',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_5',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_5'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_6',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_6',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_6'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DATAEXPORT_TOOTHFORCE_GLOBAL_FFT_7',
                                  filename='Forces_Files/IkerMAQ_ToothForce_Global_7',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_7'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

lastInstance = HarmonicForceOptiStructDataExport(name='DataExport_ToothForce_Global_FFT_1_duplicata',
                                  filename='result/IkerMAQ_ToothForce_Global_1',
                                  collection=CollectionForOSHarmonicForceExport['DATACOLLECTION_TOOTHFORCE_FFT_1'],
                                  exportedHarmonics=AllHarmonics(),
                                  forceDefinitionType='global')

fluxTool.addExtensionToAllFile('result/IkerMAQ_ToothForce_Global_1.fem', '.txt')

closeIODataContext()

saveProject()
